==> POCSdk-1.0.52-sources.jar: com/xdja/poc/sdk/event/GroupEvent.java <==
package com.xdja.poc.sdk.event;

import android.support.annotation.Keep;

import com.xdja.poc.common.event.BaseEvent;
import com.xdja.poc.sdk.bean.POCMemberInfo;

import java.util.List;
import java.util.Map;

/**
 * janus-gateway-android-master
 * 功能
 * 描述
 * created by Wwq : 2018/9/25
 */
@Keep
public class GroupEvent extends BaseEvent {
    private int eventTyep;
    private String groupName;
    private int code;
    private String roomId;
    private String members;
    private int position;
    private String from;
    private Map<String,POCMemberInfo> userInfo;

    public GroupEvent() {
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getRoomId() {
        return roomId;
    }

    public void setRoomId(String roomId) {
        this.roomId = roomId;
    }

    public int getEventTyep() {
        return eventTyep;
    }

    public void setEventTyep(int eventTyep) {
        this.eventTyep = eventTyep;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getMembers() {
        return members;
    }

    public void setMembers(String members) {
        this.members = members;
    }

    public int getPosition() {
        return position;
    }

    public void setPosition(int position) {
        this.position = position;
    }

    public Map<String, POCMemberInfo> getUserInfo() {
        return userInfo;
    }

    public void setUserInfo(Map<String, POCMemberInfo> userName) {
        this.userInfo = userName;
    }

    public String getFrom() {
        return from;
    }

    public void setFrom(String from) {
        this.from = from;
    }
}

==> POCSdk-1.0.54-sources.jar: com/xdja/poc/sdk/event/GroupEvent.java <==
package com.xdja.poc.sdk.event;

import android.support.annotation.Keep;

import com.xdja.poc.common.event.BaseEvent;
import com.xdja.poc.sdk.bean.POCMemberInfo;

import java.util.List;
import java.util.Map;

/**
 * janus-gateway-android-master
 * 功能
 * 描述
 * created by Wwq : 2018/9/25
 */
@Keep
public class GroupEvent extends BaseEvent {
    private int eventTyep;
    private String groupName;
    private int code;
    private String roomId;
    private String members;
    private int position;
    private String from;
    private Map<String,POCMemberInfo> userInfo;
    private int deviceType;

    public GroupEvent() {
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getRoomId() {
        return roomId;
    }

    public void setRoomId(String roomId) {
        this.roomId = roomId;
    }

    public int getEventTyep() {
        return eventTyep;
    }

    public void setEventTyep(int eventTyep) {
        this.eventTyep = eventTyep;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getMembers() {
        return members;
    }

    public void setMembers(String members) {
        this.members = members;
    }

    public int getPosition() {
        return position;
    }

    public void setPosition(int position) {
        this.position = position;
    }

    public Map<String, POCMemberInfo> getUserInfo() {
        return userInfo;
    }

    public void setUserInfo(Map<String, POCMemberInfo> userName) {
        this.userInfo = userName;
    }

    public String getFrom() {
        return from;
    }

    public void setFrom(String from) {
        this.from = from;
    }

    public int getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(int deviceType) {
        this.deviceType = deviceType;
    }
}
